Parametric tests for Multiple Comparison — STAC 0.7 documentation

### Navigation

- index
- STAC 0.7 documentation »

# Parametric tests for Multiple Comparison

ANOVA tests

`anova_test`(*args) | Performs a 1-way ANOVA.
`anova_within_test`(*args) | Performs a 1-way ANOVA within cases.

Post-hoc tests

`bonferroni_test`(pivots, n) | Performs a Bonferroni-Dunn post-hoc test using the pivot quantities obtained by an ANOVA test.

### Navigation

- index
- STAC 0.7 documentation »